from netbox.settings import VERSION # type: ignore
if VERSION.startswith("3."):
    from extras.plugins import PluginConfig # type: ignore
else:
    from netbox.plugins import PluginConfig # type: ignore

class IPCalcultorConfig(PluginConfig):
    name = 'netbox_ipcalculator'
    verbose_name = 'IP Calculator'
    description = 'Netbox IP Calculator'
    version = '1.4.3'
    author = 'Pieter Lambrecht'
    author_email = 'pieter.lambrecht@gmail.com'
    base_url = 'netbox_ipcalculator'
    min_version = '3.0'
    required_settings = []
    default_settings = {
        'loud': False
    }
    caching_config = {
        '*': None
    }

config = IPCalcultorConfig



from django.shortcuts import render
from django.views.generic import View

class IPCalculatorView(View):

    def get(self, request):
        return render(request, 'netbox_ipcalculator/ipcalcbase.html', {
        })


from netbox.settings import VERSION
if VERSION.startswith("3."):
    from extras.plugins import PluginTemplateExtension
else:
    from netbox.plugins import PluginTemplateExtension
import json

class IPCalcAggregate(PluginTemplateExtension):
    model = 'ipam.aggregate'

    def right_page(self):
        output=self.render('netbox_ipcalculator/core/ipcalc.html', extra_context={
            'prefix': self.context["object"]
        })        
        return output

class IPCalcPrefix(PluginTemplateExtension):
    model = 'ipam.prefix'

    def right_page(self):
        output=self.render('netbox_ipcalculator/core/ipcalc.html', extra_context={
            'prefix': self.context["object"]
        })        
        return output

class IPCalcIPAddress(PluginTemplateExtension):
    model = 'ipam.ipaddress'

    def right_page(self):
        output=self.render('netbox_ipcalculator/core/ipcalc.html', extra_context={
            'prefix': self.context["object"]
        })        
        return output

template_extensions = [IPCalcAggregate,IPCalcPrefix,IPCalcIPAddress]



from netbox.settings import VERSION
if VERSION.startswith("3."):
    from extras.plugins import PluginMenuItem
else:
    from netbox.plugins import PluginMenuItem

menu_items = (
    PluginMenuItem(
        link='plugins:netbox_ipcalculator:ipcalculator',
        link_text='IP Calculator',
    ),
)



from setuptools import find_packages, setup

# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name='netbox_ipcalculator',
    version='1.4.3',
    description='Netbox IP Calculator',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/PieterL75/netbox_ipcalculator',
    author='Pieter Lambrecht',
    license='Apache 2.0',
    install_requires=[],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
)
